@@ -117,20 +117,27 @@ fit.mpt <- function(data, model.filename, restrictions.filename = NULL, n.optim
 	# gradient and hessian:
 	
 	llk.function <- tryCatch(.make.llk.function(tree, param.names, length.param.names), error = function(e) {warning("likelihood function cannot be build"); NULL})
-	llk.gradient <- tryCatch(.make.llk.gradient(llk.function, param.names, length.param.names), error = function(e) {warning("gradient function cannot be build (probably derivation failure, see ?D"); NULL})
-	llk.hessian <- tryCatch(.make.llk.hessian(llk.function, param.names, length.param.names), error = function(e) {warning("hessian function cannot be build (probably derivation failure, see ?D"); NULL})
+	llk.gradient <- tryCatch(.make.llk.gradient(llk.function, param.names, length.param.names), error = function(e) {message("gradient function cannot be build (probably derivation failure, see ?D"); NULL})
+	llk.hessian <- tryCatch(.make.llk.hessian(llk.function, param.names, length.param.names), error = function(e) {message("hessian function cannot be build (probably derivation failure, see ?D"); NULL})
 	
 	if (!is.null(fia)) {
 		if (multiFit) {
 			data.new <- rbind(data, apply(data,2,sum))
-			fia.tmp <- get.mpt.fia(data.new, model.filename, restrictions.filename, fia, model.type, multicore = if (multicore[1] != "none") TRUE else FALSE)
-			fia.df <- fia.tmp[-dim(fia.tmp)[1],]
-			fia.agg.tmp <- fia.tmp[dim(fia.tmp)[1],]
-			fia.df <- list(fia.df, fia.agg.tmp)
+			fia.tmp <- tryCatch(get.mpt.fia(data.new, model.filename, restrictions.filename, fia, model.type, multicore = if (multicore[1] != "none") TRUE else FALSE), error = function(e) NULL)
+			if (!is.null(fia.tmp)) {
+			  fia.df <- fia.tmp[-dim(fia.tmp)[1],]
+			  fia.agg.tmp <- fia.tmp[dim(fia.tmp)[1],]
+			  fia.df <- list(fia.df, fia.agg.tmp)
+			} else fia.df <- NULL
 		} else {
-			fia.df <- get.mpt.fia(data, model.filename, restrictions.filename, fia, model.type, multicore = if (multicore[1] != "none") TRUE else FALSE)
+			fia.df <- tryCatch(get.mpt.fia(data, model.filename, restrictions.filename, fia, model.type, multicore = if (multicore[1] != "none") TRUE else FALSE), error = function(e) NULL)
+		}
+		if (is.null(fia.df)) {
+		  warning("Calculation of FIA failed. Model does not seem to be a BMPT!")
+		  fia <- NULL
 		}
 	}
+
 	
 	# call the workhorse:	
 	fit.mptinr(data = data, objective = llk.model, param.names = param.names, categories.per.type = categories.per.type, gradient = llk.gradient.funct, use.gradient = TRUE, hessian = llk.hessian.funct, use.hessian = TRUE, prediction = model.predictions, n.optim = n.optim, fia.df = if(!is.null(fia)) fia.df, ci = ci, starting.values = starting.values, lower.bound = 0, upper.bound = 1, output = output, orig.params = orig.params, fit.aggregated = fit.aggregated, sort.param = sort.param, show.messages = show.messages, use.restrictions = use.restrictions, restrictions = restrictions, multicore = multicore, sfInit = sfInit, nCPU = nCPU, control = control, unlist.model = unlist(tree), llk.gradient = llk.gradient, llk.hessian = llk.hessian)
